@@ -4,9 +4,9 @@ from .cloob import CLOOB
 from .deep_image_prior import DeepImagePrior
 from .glide_clip import GlideCLIP
 from .guided_diffusion import GuidedDiffusion
-from .k_diffusion import KDiffusion
 from . import latent_diffusion
 from .midas_depth import MidasDepth
+from .monster_diffusion import MonsterDiffusion
 from .ruclip import RuCLIP
 from .slip import SLIP
 from .stylegan_xl import StyleGANXL
